@@ -5,7 +5,6 @@
  * You may distribute under the terms of either the GNU General Public
  * License or the Artistic License, as specified in the Perl README file.
  */
-
 #include "dbdodbc.h"	/* Get SQL_* defs *before* loading DBIXS.h	*/
 
 #define NEED_DBIXS_VERSION 9
@@ -36,9 +35,10 @@ int  odbc_get_special_columns _((SV *dbh, SV *sth, int Identifier, char *Catalog
 int  odbc_get_foreign_keys _((SV *dbh, SV *sth, char *PK_CatalogName, char *PK_SchemaName, char *PK_TableName, char *FK_CatalogName, char *FK_SchemaName, char *FK_TableName));
 void dbd_error _((SV *h, RETCODE err_rc, char *what));
 void dbd_error2 _((SV *h, RETCODE err_rc, char *what, HENV henv, HDBC hdbc, HSTMT hstmt));
-int dbd_db_execdirect _(( SV *dbh, SV *statement ));
+SQLLEN dbd_db_execdirect _(( SV *dbh, SV *statement ));
 IV odbc_st_lob_read(SV *sth, int colno, SV *data, UV length, IV type);
 IV odbc_st_execute_for_fetch(SV *sth, SV *tuples, IV count, SV *tuple_status);
+IV odbc_st_rowcount(SV *sth);
 int dbd_st_statistics(SV *dbh, SV *sth, char *catalog, char *schema,
                       char *table, int unique, int quick);
 int dbd_st_bind_col(SV *sth, imp_sth_t *imp_sth, SV *col, SV *ref,
